@@ -47,8 +47,10 @@ from tendenci.apps.profiles.forms import (ProfileForm, ExportForm,
 UserPermissionForm, UserGroupsForm, ValidatingPasswordChangeForm,
 UserMembershipForm, ProfileMergeForm, ProfileSearchForm)
 from tendenci.apps.profiles.tasks import ExportProfilesTask
+from tendenci.apps.profiles.utils import get_member_reminders
 from tendenci.addons.events.models import Registrant
-from tendenci.addons.memberships.models import MembershipType, MembershipDefault
+from tendenci.addons.memberships.models import MembershipType
+from tendenci.apps.invoices.models import Invoice
 
 try:
     notification = get_app('notifications')
@@ -80,10 +82,9 @@ def index(request, username='', template_name="profiles/index.html"):
 
     # content counts
     content_counts = {'total': 0, 'invoice': 0}
-    from tendenci.apps.invoices.models import Invoice
-    inv_count = Invoice.objects.filter(Q(creator=user_this) | Q(owner=user_this), Q(bill_to_email=user_this.email)).count()
-    if request.user.profile.is_superuser:
-        inv_count = Invoice.objects.filter(Q(creator=user_this) | Q(owner=user_this) | Q(bill_to_email=user_this.email)).count()
+
+    inv_count = Invoice.objects.filter(Q(owner=user_this) |
+                                        Q(bill_to_email=user_this.email)).count()
     content_counts['invoice'] = inv_count
     content_counts['total'] += inv_count
 
@@ -143,6 +144,10 @@ def index(request, username='', template_name="profiles/index.html"):
     else:
         membership_apps = None
 
+    membership_reminders = ()
+    if request.user == user_this:
+        membership_reminders = get_member_reminders(user_this)
+
     return render_to_response(template_name, {
         'can_edit': can_edit,
         "user_this": user_this,
@@ -155,7 +160,8 @@ def index(request, username='', template_name="profiles/index.html"):
         'memberships': memberships,
         'registrations': registrations,
         'membership_apps': membership_apps,
-        'multiple_apps': multiple_apps
+        'multiple_apps': multiple_apps,
+        'membership_reminders': membership_reminders,
         }, context_instance=RequestContext(request))
 
 
